API Reference
-------------

icalendar.cal
+++++++++++++

.. automodule:: icalendar.cal
   :members:

icalendar.caselessdict
++++++++++++++++++++++

.. automodule:: icalendar.caselessdict
   :members:

icalendar.cli
+++++++++++++

.. automodule:: icalendar.cli
   :members:

icalendar.parser
++++++++++++++++

.. automodule:: icalendar.parser
   :members:

icalendar.parser_tools
++++++++++++++++++++++

.. automodule:: icalendar.parser_tools
   :members:

icalendar.prop
++++++++++++++

.. automodule:: icalendar.prop
   :members:

icalendar.tools
+++++++++++++++

.. automodule:: icalendar.tools
   :members:
